@@ -14,7 +14,7 @@ use File::Glob qw(:bsd_glob);
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 use Data::Dump qw(dump);
 
-our $VERSION = '2017.117';
+our $VERSION = '2017.201';
 
 &saveToS3('DataTableText') if 0;                                                # Save code
 
@@ -155,7 +155,7 @@ sub formatTableBasic($;$)
     for my $D(0..$#$e)
      {my $m = $D[$D];                                                           # Maximum width
       my $i = $e->[$D]//'';                                                     # Current item
-      if ($i !~ /\A\s*[-+]?\s*\d+(\.\d+)?([Ee]\s*[-+]?\s*\d+)?\s*\Z/)           # Not a number - left justify
+      if ($i !~ /\A\s*[-+]?\s*[0-9,]+(\.\d+)?([Ee]\s*[-+]?\s*\d+)?\s*\Z/)       # Not a number - left justify
        {$t .= substr($i.(' 'x$m), 0, $m)."  ";
        }
       else                                                                      # Number - right justify
